@@ -1,4 +1,5 @@
-""" ComfoConnect Property definitions. """
+""" Property definitions """
+from __future__ import annotations
 
 from dataclasses import dataclass
 
@@ -13,10 +14,12 @@ from .const import (
 
 @dataclass
 class Property:
+    """Dataclass for a Property"""
+
     unit: int
     subunit: int
-    id: int
-    type: int
+    property_id: int
+    property_type: int
 
 
 PROPERTY_SERIAL_NUMBER = Property(UNIT_NODE, 0x01, 0x04, TYPE_CN_STRING)
