@@ -1,4 +1,5 @@
 """ Helper methods. """
+from __future__ import annotations
 
 
 def bytestring(arr):
@@ -6,11 +7,11 @@ def bytestring(arr):
     return b"".join([i if isinstance(i, bytes) else bytes([i]) for i in arr])
 
 
-def bytearray_to_bits(bytearray):
+def bytearray_to_bits(arr):
     """Convert a bytearray to a list of set bits."""
     bits = []
     j = 0
-    for byte in bytearray:
+    for byte in arr:
         for i in range(8):
             if byte & (1 << i):
                 bits.append(j)
@@ -20,21 +21,21 @@ def bytearray_to_bits(bytearray):
 
 def version_decode(version):
     """Decode the version number to a string."""
-    v1 = (version >> 30) & 3
-    v2 = (version >> 20) & 1023
-    v3 = (version >> 10) & 1023
-    v4 = version & 1023
+    v_1 = (version >> 30) & 3
+    v_2 = (version >> 20) & 1023
+    v_3 = (version >> 10) & 1023
+    v_4 = version & 1023
 
-    if v1 == 0:
-        v1 = "U"
-    elif v1 == 1:
-        v1 = "D"
-    elif v1 == 2:
-        v1 = "P"
-    elif v1 == 3:
-        v1 = "R"
+    if v_1 == 0:
+        v_1 = "U"
+    elif v_1 == 1:
+        v_1 = "D"
+    elif v_1 == 2:
+        v_1 = "P"
+    elif v_1 == 3:
+        v_1 = "R"
 
-    return "%s%s.%s.%s" % (v1, v2, v3, v4)
+    return f"{v_1}{v_2}.{v_3}.{v_4}"
 
 
 def pdo_to_can(pdo, node_id=1):
